==> deepin-system-monitor_6.0.7.tar.xz: BUILD/deepin-system-monitor-plugin-popup/translations/deepin-system-monitor-plugin-popup_id.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="id" version="2.1">
<context>
    <name>Common.Search</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="130"/>
        <source>No search results</source>
        <translation>Tidak ada hasil pencarian</translation>
    </message>
</context>
<context>
    <name>Cpu.Widget</name>
    <message>
        <location filename="../gui/cpu_widget.cpp" line="180"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
</context>
<context>
    <name>CpuWidget</name>
    <message>
        <location filename="../gui/cpu_widget.cpp" line="216"/>
        <location filename="../gui/cpu_widget.cpp" line="217"/>
        <source>Utilization</source>
        <translation>Pemanfaatan</translation>
    </message>
</context>
<context>
    <name>Disk.Widget</name>
    <message>
        <location filename="../gui/disk_widget.cpp" line="228"/>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <location filename="../gui/disk_widget.cpp" line="258"/>
        <source>Read</source>
        <translation>Baca</translation>
    </message>
    <message>
        <location filename="../gui/disk_widget.cpp" line="259"/>
        <source>Write</source>
        <translation>Tulis</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <location filename="../common/common.cpp" line="42"/>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="48"/>
        <source>Display shortcuts</source>
        <translation>Tampilkan pemintas</translation>
    </message>
</context>
<context>
    <name>Memory.Widget</name>
    <message>
        <location filename="../gui/memory_widget.cpp" line="152"/>
        <source>Memory</source>
        <translation>Memori</translation>
    </message>
    <message>
        <location filename="../gui/memory_widget.cpp" line="179"/>
        <location filename="../gui/memory_widget.cpp" line="188"/>
        <source>Swap</source>
        <translation>Swap</translation>
    </message>
    <message>
        <location filename="../gui/memory_widget.cpp" line="180"/>
        <source>Not enabled</source>
        <translation>Tidak diaktifkan</translation>
    </message>
</context>
<context>
    <name>Net.Widget</name>
    <message>
        <location filename="../gui/net_widget.cpp" line="259"/>
        <source>Download</source>
        <translation>Unduh</translation>
    </message>
    <message>
        <location filename="../gui/net_widget.cpp" line="260"/>
        <source>Total received</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../gui/net_widget.cpp" line="262"/>
        <source>Total sent</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../gui/net_widget.cpp" line="261"/>
        <source>Upload</source>
        <translation>Unggah</translation>
    </message>
</context>
<context>
    <name>NetWidget</name>
    <message>
        <location filename="../gui/net_widget.cpp" line="232"/>
        <location filename="../gui/net_widget.cpp" line="235"/>
        <source>Network</source>
        <translation>Jaringan</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <location filename="../process/process.cpp" line="67"/>
        <source>Very high</source>
        <translation>Sangat tinggi</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="68"/>
        <source>High</source>
        <translation>Tinggi</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="69"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="70"/>
        <source>Low</source>
        <translation>Rendah</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="71"/>
        <source>Very low</source>
        <translation>Sangat rendah</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="72"/>
        <source>Custom</source>
        <translation>Kustom</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="73"/>
        <source>Invalid</source>
        <translation>Tidak valid</translation>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <location filename="../process/process_db.cpp" line="162"/>
        <source>Failed to end process</source>
        <translation>Gagal mengakhiri proses</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="165"/>
        <source>Failed to pause process</source>
        <translation>Gagal menjeda proses</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="168"/>
        <source>Failed to resume process</source>
        <translation>Gagal melanjutkan proses</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="171"/>
        <source>Failed to kill process</source>
        <translation>Gagal mematikan proses</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="174"/>
        <source>Unknown error</source>
        <translation>Galat tidak diketahui</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="224"/>
        <source>Failed in sending signal to process</source>
        <translation>Gagal mengirim sinyal ke proses</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <location filename="../model/process_table_model.cpp" line="175"/>
        <source>No response</source>
        <translation>Tak ada respons</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.cpp" line="180"/>
        <source>Suspend</source>
        <translation>Tangguhkan</translation>
    </message>
    <message>
        <location filename="../process/process_name.cpp" line="96"/>
        <location filename="../process/process_name.cpp" line="103"/>
        <location filename="../process/process_name.cpp" line="106"/>
        <source>Tray</source>
        <translation>Baki</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="76"/>
        <source>End process</source>
        <translation>Akhiri proses</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="82"/>
        <source>Suspend process</source>
        <translation>Tangguhkan proses</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="88"/>
        <source>Resume process</source>
        <translation>Lanjutkan proses</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="93"/>
        <source>Properties</source>
        <translation>Properti</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="99"/>
        <source>Kill process</source>
        <translation>Matikan proses</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <location filename="../model/process_table_model.h" line="31"/>
        <source>Name</source>
        <translation>Nama</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="33"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="35"/>
        <source>User</source>
        <translation>Pengguna</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="37"/>
        <source>Memory</source>
        <translation>Memori</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="38"/>
        <source>Shared memory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="39"/>
        <source>Virtual memory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="41"/>
        <source>Upload</source>
        <translation>Unggah</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="43"/>
        <source>Download</source>
        <translation>Unduh</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="45"/>
        <source>Disk read</source>
        <translation>Baca disk</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="47"/>
        <source>Disk write</source>
        <translation>Tulis disk</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="49"/>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="51"/>
        <source>Nice</source>
        <translation>Nice</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="53"/>
        <source>Priority</source>
        <translation>Prioritas</translation>
    </message>
</context>
<context>
    <name>ProcessWidget</name>
    <message>
        <location filename="../gui/process_widget.cpp" line="65"/>
        <source>Name</source>
        <translation>Nama</translation>
    </message>
    <message>
        <location filename="../gui/process_widget.cpp" line="72"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../gui/process_widget.cpp" line="182"/>
        <location filename="../gui/process_widget.cpp" line="185"/>
        <source>Processes</source>
        <translation>Proses</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../system/cpu_set.cpp" line="267"/>
        <source>Not support</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="113"/>
        <source>Start</source>
        <translation>Mulai</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="118"/>
        <source>Stop</source>
        <translation>Setop</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="123"/>
        <source>Restart</source>
        <translation>Mulai ulang</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="128"/>
        <source>Refresh</source>
        <translation>Segarkan</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="69"/>
        <source>Force end application</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <location filename="../common/common.cpp" line="54"/>
        <source>Search</source>
        <translation>Cari</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <location filename="../common/common.cpp" line="63"/>
        <source>Processes</source>
        <translation>Proses</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="108"/>
        <source>Services</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> deepin-system-monitor_6.5.12.tar.xz: BUILD/deepin-system-monitor-plugin-popup/translations/deepin-system-monitor-plugin-popup_id.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="id" version="2.1">
<context>
    <name>Common.Search</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="130"/>
        <source>No search results</source>
        <translation>Tidak ada hasil pencarian</translation>
    </message>
</context>
<context>
    <name>Cpu.Widget</name>
    <message>
        <location filename="../gui/cpu_widget.cpp" line="180"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
</context>
<context>
    <name>CpuWidget</name>
    <message>
        <location filename="../gui/cpu_widget.cpp" line="216"/>
        <location filename="../gui/cpu_widget.cpp" line="217"/>
        <source>Utilization</source>
        <translation>Pemanfaatan</translation>
    </message>
</context>
<context>
    <name>Disk.Widget</name>
    <message>
        <location filename="../gui/disk_widget.cpp" line="228"/>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <location filename="../gui/disk_widget.cpp" line="258"/>
        <source>Read</source>
        <translation>Baca</translation>
    </message>
    <message>
        <location filename="../gui/disk_widget.cpp" line="259"/>
        <source>Write</source>
        <translation>Tulis</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <location filename="../common/common.cpp" line="42"/>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="48"/>
        <source>Display shortcuts</source>
        <translation>Tampilkan pemintas</translation>
    </message>
</context>
<context>
    <name>Memory.Widget</name>
    <message>
        <location filename="../gui/memory_widget.cpp" line="152"/>
        <source>Memory</source>
        <translation>Memori</translation>
    </message>
    <message>
        <location filename="../gui/memory_widget.cpp" line="179"/>
        <location filename="../gui/memory_widget.cpp" line="188"/>
        <source>Swap</source>
        <translation>Swap</translation>
    </message>
    <message>
        <location filename="../gui/memory_widget.cpp" line="180"/>
        <source>Not enabled</source>
        <translation>Tidak diaktifkan</translation>
    </message>
</context>
<context>
    <name>Net.Widget</name>
    <message>
        <location filename="../gui/net_widget.cpp" line="259"/>
        <source>Download</source>
        <translation>Unduh</translation>
    </message>
    <message>
        <location filename="../gui/net_widget.cpp" line="260"/>
        <source>Total received</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../gui/net_widget.cpp" line="262"/>
        <source>Total sent</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../gui/net_widget.cpp" line="261"/>
        <source>Upload</source>
        <translation>Unggah</translation>
    </message>
</context>
<context>
    <name>NetWidget</name>
    <message>
        <location filename="../gui/net_widget.cpp" line="232"/>
        <location filename="../gui/net_widget.cpp" line="235"/>
        <source>Network</source>
        <translation>Jaringan</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <location filename="../process/process.cpp" line="67"/>
        <source>Very high</source>
        <translation>Sangat tinggi</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="68"/>
        <source>High</source>
        <translation>Tinggi</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="69"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="70"/>
        <source>Low</source>
        <translation>Rendah</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="71"/>
        <source>Very low</source>
        <translation>Sangat rendah</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="72"/>
        <source>Custom</source>
        <translation>Kustom</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="73"/>
        <source>Invalid</source>
        <translation>Tidak valid</translation>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <location filename="../process/process_db.cpp" line="162"/>
        <source>Failed to end process</source>
        <translation>Gagal mengakhiri proses</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="165"/>
        <source>Failed to pause process</source>
        <translation>Gagal menjeda proses</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="168"/>
        <source>Failed to resume process</source>
        <translation>Gagal melanjutkan proses</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="171"/>
        <source>Failed to kill process</source>
        <translation>Gagal mematikan proses</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="174"/>
        <source>Unknown error</source>
        <translation>Galat tidak diketahui</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="224"/>
        <source>Failed in sending signal to process</source>
        <translation>Gagal mengirim sinyal ke proses</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <location filename="../model/process_table_model.cpp" line="175"/>
        <source>No response</source>
        <translation>Tak ada respons</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.cpp" line="180"/>
        <source>Suspend</source>
        <translation>Tangguhkan</translation>
    </message>
    <message>
        <location filename="../process/process_name.cpp" line="96"/>
        <location filename="../process/process_name.cpp" line="103"/>
        <location filename="../process/process_name.cpp" line="106"/>
        <source>Tray</source>
        <translation>Baki</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="76"/>
        <source>End process</source>
        <translation>Akhiri proses</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="82"/>
        <source>Suspend process</source>
        <translation>Tangguhkan proses</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="88"/>
        <source>Resume process</source>
        <translation>Lanjutkan proses</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="93"/>
        <source>Properties</source>
        <translation>Properti</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="99"/>
        <source>Kill process</source>
        <translation>Matikan proses</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <location filename="../model/process_table_model.h" line="31"/>
        <source>Name</source>
        <translation>Nama</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="33"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="35"/>
        <source>User</source>
        <translation>Pengguna</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="37"/>
        <source>Memory</source>
        <translation>Memori</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="38"/>
        <source>Shared memory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="39"/>
        <source>Virtual memory</source>
        <translation>Memori virtual</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="41"/>
        <source>Upload</source>
        <translation>Unggah</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="43"/>
        <source>Download</source>
        <translation>Unduh</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="45"/>
        <source>Disk read</source>
        <translation>Baca diska</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="47"/>
        <source>Disk write</source>
        <translation>Tulis diska</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="49"/>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="51"/>
        <source>Nice</source>
        <translation>Nice</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="53"/>
        <source>Priority</source>
        <translation>Prioritas</translation>
    </message>
</context>
<context>
    <name>ProcessWidget</name>
    <message>
        <location filename="../gui/process_widget.cpp" line="65"/>
        <source>Name</source>
        <translation>Nama</translation>
    </message>
    <message>
        <location filename="../gui/process_widget.cpp" line="72"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../gui/process_widget.cpp" line="182"/>
        <location filename="../gui/process_widget.cpp" line="185"/>
        <source>Processes</source>
        <translation>Proses</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../system/cpu_set.cpp" line="267"/>
        <source>Not support</source>
        <translation>Tidak didukung</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="113"/>
        <source>Start</source>
        <translation>Mulai</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="118"/>
        <source>Stop</source>
        <translation>Setop</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="123"/>
        <source>Restart</source>
        <translation>Mulai ulang</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="128"/>
        <source>Refresh</source>
        <translation>Segarkan</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="69"/>
        <source>Force end application</source>
        <translation>Paksa akhiri aplikasi</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <location filename="../common/common.cpp" line="54"/>
        <source>Search</source>
        <translation>Cari</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <location filename="../common/common.cpp" line="63"/>
        <source>Processes</source>
        <translation>Proses</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="108"/>
        <source>Services</source>
        <translation>Layanan</translation>
    </message>
</context>
</TS>
